==> library1.4.1.tar.bz2: library/film-zakupka-search.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "utils/chlang_osn.php";

$title = $TEXT['menu-btn32-title'];

require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top_film.php";

if($result2['administrator'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom_film.php"; exit();}
if(strlen($_GET['k'])>8) {puterror2($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom_film.php"; exit();}
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
?>
<table align="center" border="0" cellpadding="3" cellspacing="0" width="70%">
 <thead><tr class='tableheadercat'>
<td><?php echo $TEXT['film-name']; ?></td>
<td><?php echo $TEXT['global-film']; ?></td>
<td><?php echo $TEXT['book-who-zak']; ?></td>
<td><?php echo $TEXT['book-data5']; ?></td>
</tr>
 </thead>
<tbody id="tab" >
<?php
     $query_body = "SELECT
     tbl_film.film_name,
     tbl_film.film_id,
     YEAR(tbl_film.data_vidachi) AS data_vidachi_year,
     MONTH(tbl_film.data_vidachi) AS data_vidachi_month,
     DAY(tbl_film.data_vidachi) AS data_vidachi_day,
     tbl_film.user_id,
     tbl_film.vidano,
     tbl_biblioteka.name AS bibl_name,
     tbl_logins.familiya,
     tbl_logins.name,
     tbl_logins.otchestvo
     FROM tbl_film
     JOIN tbl_biblioteka ON tbl_film.bibl_id=tbl_biblioteka.bibl_id
     JOIN tbl_logins ON tbl_film.user_id=tbl_logins.login_id
     WHERE tbl_film.vidano='3'
     ORDER BY tbl_film.data_vidachi DESC, tbl_film.film_name ASC
     LIMIT $lim_ogr ";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl26']); require_once "utils/bottom_film.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows  > 0)
         {
          while($result_body_film= mysqli_fetch_array($result_body))
               {
               $date_day = $result_body_film['data_vidachi_day'];
               $date_month = $result_body_film['data_vidachi_month'];
               $date_year = $result_body_film['data_vidachi_year'];
               $year = $TEXT['year2'];
               if($date_year == "0000" || $date_year == "1970") {$data_zak = "---";}
                else {$data_zak = (date("$date_day $month[$date_month] $date_year $year"));}

               $bibl = $result_body_film['bibl_name'];
               $film_name = "<a href=film-info.php?film_id=".$result_body_film['film_id']." title='".$TEXT['aut-viewtit']."'>".rep_back($result_body_film['film_name'])."</a>";

               ?>
               <tr>
                <td class="informcntr"><?php echo $film_name; ?></td>
                <td><?php echo $bibl; ?></td>
                <td><?php echo $result_body_film['familiya']; ?> <?php echo $result_body_film['name']; ?> <?php echo $result_body_film['otchestvo']; ?></td>
                <td><?php echo $data_zak; ?></td>
               </tr>
               <?php
               }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(film_id) AS c_film_id FROM tbl_film WHERE zakazano ='1'");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_film_id']/10;
               if($pag<1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='film-zakupka-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='film-zakupka-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=film-zakupka-search.php?k=".$k.">".$j."</option>";}
                       else {echo "<option value=film-zakupka-search.php?k=".$k.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
  require_once "utils/bottom_film.php";
?>

==> library1.19.1.tar.bz2: library/film-zakupka-search.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "utils/chlang_osn.php";

$title = $TEXT['menu-btn32-title'];

require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top_film.php";

if($result2['administrator'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom_film.php"; exit();}
if(strlen($_GET['k'])>8) {puterror2($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom_film.php"; exit();}
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
?>
<table align="center" border="0" cellpadding="3" cellspacing="0" width="70%">
 <thead><tr class="tableheadercat">
<td><?php echo $TEXT['film-name']; ?></td>
<td><?php echo $TEXT['global-film']; ?></td>
<td><?php echo $TEXT['book-who-zak']; ?></td>
<td><?php echo $TEXT['book-data5']; ?></td>
</tr>
 </thead>
<tbody id="tab" >
<?php
     $query_body = "SELECT
     tbl_film.data_vidachi,
     tbl_film.film_name,
     tbl_film.film_id,
     YEAR(tbl_film.data_vidachi) AS data_vidachi_year,
     MONTH(tbl_film.data_vidachi) AS data_vidachi_month,
     DAY(tbl_film.data_vidachi) AS data_vidachi_day,
     tbl_film.user_id,
     tbl_film.vidano,
     tbl_biblioteka.name AS bibl_name,
     tbl_logins.familiya,
     tbl_logins.name,
     tbl_logins.otchestvo
     FROM tbl_film
     JOIN tbl_biblioteka ON tbl_film.bibl_id=tbl_biblioteka.bibl_id
     JOIN tbl_logins ON tbl_film.user_id=tbl_logins.login_id
     WHERE tbl_film.vidano='3'
     ORDER BY tbl_film.data_vidachi DESC, tbl_film.film_name ASC
     LIMIT $lim_ogr ";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl26']); require_once "utils/bottom_film.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows  > 0)
         {
          while($result_body_film= mysqli_fetch_array($result_body))
               {
               $date_day = $result_body_film['data_vidachi_day'];
               $date_month = $result_body_film['data_vidachi_month'];
               $date_year = $result_body_film['data_vidachi_year'];
               $year = $TEXT['year2'];
               if($date_year == "0000" || $date_year == "1970") {$data_zak = "---";}
                else {$data_zak = (date("$date_day $month[$date_month] $date_year $year"));}

               $bibl = $result_body_film['bibl_name'];
               $film_name = "<a href=film-info.php?film_id=".$result_body_film['film_id']." title='".$TEXT['aut-viewtit']."'>".rep_back($result_body_film['film_name'])."</a>";

               ?>
               <tr>
                <td class="informcntr"><?php echo $film_name; ?></td>
                <td><?php echo $bibl; ?></td>
                <td><?php echo $result_body_film['familiya']; ?> <?php echo $result_body_film['name']; ?> <?php echo $result_body_film['otchestvo']; ?></td>
                <td><?php echo $data_zak; ?></td>
               </tr>
               <?php
               }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(film_id) AS c_film_id FROM tbl_film WHERE zakazano ='1'");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_film_id']/10;
               if($pag<1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='film-zakupka-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='film-zakupka-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=film-zakupka-search.php?k=".$k.">".$j."</option>";}
                       else {echo "<option value=film-zakupka-search.php?k=".$k.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
  require_once "utils/bottom_film.php";
?>
